@@ -573,7 +573,18 @@ class FluxAgent:
                     except subprocess.CalledProcessError:
                         log.error("Error loading extensions packages, skipping")
                         return
-                self.extensions.add_plugin(plugin)
+                    try:
+                        runner = importlib.import_module(f"{f}/_runner.py")
+                    except Exception as e:
+                        print(repr(e))
+                    else:
+                        plugin = runner.plugin
+                        if not isinstance(plugin, FluxVaultExtensions):
+                            log.error(
+                                f"Bad runner... plugin is not a FluxVault extensions"
+                            )
+                else:
+                    self.extensions.add_plugin(plugin)
                 log.info(f"Plugin {plugin.plugin_name} loaded")
             else:
                 log.error("Plugin load error... skipping")
